# command map
command_map = {
	"start"  : "$HADOOP_HOME/bin/start-all.sh",
	"stop"   : "$HADOOP_HOME/bin/stop-all.sh",
	"cp"     : "$HADOOP_HOME/bin/hadoop fs -cp",
	"rm"     : "$HADOOP_HOME/bin/hadoop fs -rmr",
	"ls"     : "$HADOOP_HOME/bin/hadoop fs -ls",
}